ProSHADE: src/proshade/ProSHADE_spheres.hpp File Reference

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Classes | Namespaces | Functions
ProSHADE_spheres.hpp File Reference

This header file contains the declarations for the ProSHADE_sphere class. More...

`#include "ProSHADE_sphericalHarmonics.hpp"`

Go to the source code of this file.

## Classes
class | ProSHADE_internal_spheres::ProSHADE_sphere
| This class contains all inputed and derived data for a single sphere. More...
class | ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup
| This class contains peak groups detected in the rotation function mapped spheres. More...

## Namespaces
| ProSHADE_internal_spheres
| This namespace contains the structure and functions required for storing internal map projections onto a set of concentric spheres.

## Functions
proshade_unsign | ProSHADE_internal_spheres::autoDetermineBandwidth (proshade_unsign circumference)
| This function determines the bandwidth for the spherical harmonics computation. More...
proshade_single | ProSHADE_internal_spheres::autoDetermineSphereDistances (proshade_single maxMapRange, proshade_single resolution)
| This function determines the sphere distances for sphere mapping. More...
proshade_unsign | ProSHADE_internal_spheres::autoDetermineIntegrationOrder (proshade_single maxMapRange, proshade_single sphereDist)
| This function determines the integration order for the between spheres integration. More...

## Detailed Description

This header file contains the declarations for the ProSHADE_sphere class.

The ProSHADE_sphere class and the ProSHADE_internal_spheres namespace are both declated in this header file. The functionalities that these two objects provide to ProSHADE are mapping a 3D map onto a surface of a sphere with a given radius, object for holding such a mapping and onto which the spherical harmonics decomposition could be done as well as support function for data access and processing.

Copyright by Michal Tykac and individual contributors. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met: 1) Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer. 2) Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution. 3) Neither the name of Michal Tykac nor the names of this code's contributors may be used to endorse or promote products derived from this software without specific prior written permission.

This software is provided by the copyright holder and contributors "as is" and any express or implied warranties, including, but not limitted to, the implied warranties of merchantibility and fitness for a particular purpose are disclaimed. In no event shall the copyright owner or the contributors be liable for any direct, indirect, incidental, special, exemplary, or consequential damages (including, but not limitted to, procurement of substitute goods or services, loss of use, data or profits, or business interuption) however caused and on any theory of liability, whether in contract, strict liability or tort (including negligence or otherwise) arising in any way out of the use of this software, even if advised of the possibility of such damage.

Author
  Michal Tykac
  Garib N. Murshudov

Version
  0.7.5.1

Date
  JAN 2021

Definition in file ProSHADE_spheres.hpp.